@@ -47,6 +47,7 @@
 #include "Logger.h"
 #include "Socket.h"
 #include "SimpleRandomizer.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
@@ -85,7 +86,7 @@ bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
       socket->bind(port);
       socket->beginListen();
       socket->setNonBlockingMode();
-      logger->info(MSG_LISTENING_PORT, cuid, port);
+      logger->notice("BitTorrent: listening to port %d", port);
       return true;
     } catch(RecoverableException& ex) {
       logger->error(MSG_BIND_FAILURE, ex, cuid, port);
@@ -95,6 +96,17 @@ bool PeerListenCommand::bindPort(uint16_t& port, IntSequence& seq)
   return false;
 }
 
+uint16_t PeerListenCommand::getPort() const
+{
+  if(socket.isNull()) {
+    return 0;
+  } else {
+    std::pair<std::string, uint16_t> addr;
+    socket->getAddrInfo(addr);
+    return addr.second;
+  }
+}
+
 bool PeerListenCommand::execute() {
   if(e->isHaltRequested() || e->_requestGroupMan->downloadFinished()) {
     return true;
