@@ -169,6 +169,7 @@ private:
   // returns downloadresultcode::UNKNOWN_ERROR.
   downloadresultcode::RESULT downloadResult() const;
 public:
+  // The copy of option is stored in RequestGroup object.
   RequestGroup(const SharedHandle<Option>& option);
 
   ~RequestGroup();
@@ -243,10 +244,9 @@ public:
     return _downloadContext;
   }
 
-  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext)
-  {
-    _downloadContext = downloadContext;
-  }
+  // This function also calls
+  // downloadContext->setOwnerRequestGroup(this).
+  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext);
 
   const SharedHandle<PieceStorage>& getPieceStorage() const
   {
@@ -334,13 +334,13 @@ public:
 
   void addPostDownloadHandler(const SharedHandle<PostDownloadHandler>& handler);
 
-  void clearPostDowloadHandler();
+  void clearPostDownloadHandler();
 
   void preDownloadProcessing();
 
   void addPreDownloadHandler(const SharedHandle<PreDownloadHandler>& handler);
 
-  void clearPreDowloadHandler();
+  void clearPreDownloadHandler();
 
   void processCheckIntegrityEntry(std::deque<Command*>& commands,
 				  const SharedHandle<CheckIntegrityEntry>& entry,
